# CluSim: a package for calculating clustering similarity

This package implements a series of methods used to compare Clusterings.

Installation
------------

This package is available in PyPI. Just run the following command on terminal to install.

```
    $ pip install clusim
```

You can also source the code directly from the github [project page](https://github.com/Hoosier-Clusters/clusim).

Docs
----

The full documentation can be found at: [Hoosier-Clusters.github.io/clusim](https://Hoosier-Clusters.github.io/clusim)

Papers
------

- A.J. Gates and YY Ahn [2017] "[The Impact of Random Models on Clustering Similarity.](http://jmlr.org/papers/volume18/17-039/17-039.pdf)" *JMLR* **18**, 1-28.

- A.J. Gates, I.B. Wood, W.P. Hetrick, and YY Ahn [2019]. "[Element-centric clustering comparison unifies overlaps and hierarchy](https://www.nature.com/articles/s41598-019-44892-y)". *Scientific Reports* **9**, 8574.    [arxiv:1706.06136](https://arxiv.org/abs/1706.06136)

- A.J. Gates and YY Ahn [2019]. "[CluSim: a python package for calculating clustering similarity](http://joss.theoj.org/papers/10.21105/joss.01264)". *Journal of Open Source Software* **4**(35), 1264. [![DOI](http://joss.theoj.org/papers/10.21105/joss.01264/status.svg)](https://doi.org/10.21105/joss.01264)


Contributing
------

When contributing to this repository, please first discuss the change you wish to make via issue,
email, or any other method with the owners of this repository before making a change. 

Please note we have a code of conduct, please follow it in all your interactions with the project.

### Pull request process

We recommend that you create a Git branch for each pull request (PR).  


### Code of Conduct

Please note that the *CluSim* project is released with a
[Contributor Code of Conduct](CODE_OF_CONDUCT.md). By contributing to this
project you agree to abide by its terms.

### Email Questions or Comments? 

If you prefer to email, please contact us at: ajgates42 [at] gmail [dot] com

